BenchmarkResults class

Constructors

BenchmarkResults({required double lexerTokensPerSecond, required double lexerTime, required double parserNodesPerSecond, required double parserTime, required double evaluatorTime, required double totalTime, required double memoryUsage})

Properties

evaluatorTime double
final
hashCode int
The hash code for this object.
no setterinherited
lexerTime double
final
lexerTokensPerSecond double
final
memoryUsage double
final
parserNodesPerSecond double
final
parserTime double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalTime double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited