Tart class

Constructors

Tart()

Properties

evaluator Evaluator
final
hashCode int
The hash code for this object.
no setterinherited
lexer Lexer
final
parser Parser
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

callFunction(String functionName, List arguments) → dynamic
defineGlobalFunction(String name, Function value) → void
defineGlobalVariable(String name, dynamic value) → void
getGlobalVariable(String name) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(String source) → dynamic
runAsync(String source, {bool benchmark = false}) Future<(dynamic, BenchmarkResults?)>
runWithBenchmark(String source) → (dynamic, BenchmarkResults?)
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited