Token class

Constructors

Token(TokenType type, String lexeme, Object? literal, int line)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
lexeme → String
final
line → int
final
literal → Object?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → TokenType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited