Lexer class
Constructors
- Lexer()
Properties
- current ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- line ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source ↔ String
-
getter/setter pair
- start ↔ int
-
getter/setter pair
-
tokens
→ List<
Token> -
final
Methods
-
addToken(
TokenType type, [Object? literal]) → void -
advance(
[int count = 1]) → String -
getLastToken(
) → Token -
hasNewToken(
) → bool -
identifier(
) → void -
isAlpha(
String c) → bool -
isAlphaNumeric(
String c) → bool -
isAtEnd(
) → bool -
isDigit(
String c) → bool -
match(
String expected) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
number(
) → void -
peek(
) → String? -
peekNext(
) → String? -
reset(
) → void -
scanNextToken(
) → void -
scanToken(
) → void -
scanTokens(
String source) → List< Token> -
scanTokensAsync(
String source) → Future< List< Token> > -
string(
String quote) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited